import { type Extension } from '@codemirror/state';
import { EditorView } from '@codemirror/view';
import { type DockPosition } from '../sidebar';
import { explorerThemeVariables, type ExplorerThemeVariables } from '../themes/explorer';
import { type File } from './state';
export interface ExplorerOptions {
    /**
     * Which side to dock the explorer panel on
     * @default 'left'
     */
    dock?: DockPosition;
    /**
     * Width of the explorer panel
     * @default '250px'
     */
    width?: string;
    /**
     * Whether to show the explorer panel as an overlay
     * @default false
     */
    overlay?: boolean;
    /**
     * Background color of the explorer panel
     * @default '#2c313a'
     */
    backgroundColor?: string;
    /**
     * Keyboard shortcut to toggle the explorer panel
     * @example 'Cmd-b' or { mac: 'Cmd-b', win: 'Ctrl-b' }
     */
    keymap?: string | {
        mac?: string;
        win?: string;
    };
    /**
     * Whether to open the explorer panel by default
     * @default false
     */
    initiallyOpen?: boolean;
    /**
     * Callback when a file is selected
     */
    onFileSelect?: (filename: string, view: EditorView) => void;
    /**
     * Theme for the explorer
     */
    theme?: Partial<ExplorerThemeVariables>;
}
/**
 * Creates a file explorer extension for CodeMirror
 */
export declare function explorer(options?: ExplorerOptions): Extension[];
export type { File, ExplorerThemeVariables };
export { updateFilesEffect, selectFileEffect, setProjectNameEffect, } from './state';
export { toggleExplorer } from './commands';
export { explorerThemeVariables };
